from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

setup(
    name='pyqt-windows-buttons-widget',
    version='0.0.16',
    author='Jung Gyu Yoon',
    author_email='yjg30737@gmail.com',
    license='MIT',
    packages=find_packages(),
    description='PyQt Windows titlebar buttons (e.g. min/max/close button) widget',
    url='https://github.com/yjg30737/pyqt-windows-buttons-widget.git',
    long_description_content_type='text/markdown',
    long_description=long_description,
    install_requires=[
        'PyQt5>=5.8',
        'python-color-getter>=0.0.1',
        'pyqt-titlebar-buttons-widget>=0.0.1'
    ]
)